.. _guide_transpiler:

Transpiler
============

Architecture
--------------

Hub and spokes (v0.4.5)
^^^^^^^^^^^^^^^^^^^^^^^^

.. image:: ../_static/sdk-files/hub_spokes.png
    :align: center
    :width: 70%
    :alt: Hub and spokes
    :target: javascript:void(0);

|

Graph model (v0.5.0)
^^^^^^^^^^^^^^^^^^^^^

.. image:: ../_static/sdk-files/conversion_graph.png
    :align: center
    :width: 70%
    :alt: Graph model
    :target: javascript:void(0);

|

.. seealso::

    - https://github.com/qBraid/qbraid-lab-demo/blob/main/qbraid_sdk/qbraid_sdk_transpiler.ipynb
    - https://github.com/qBraid/qbraid-lab-demo/blob/main/qbraid_sdk/qbraid_transpiler_stim.ipynb